@@ -508,7 +508,9 @@ class Model:
                 #.for
 
             if __strict and name_count > 0 and missing_names == name_count:
-                raise KeyError('{:,}'.format(self._id))
+                # Be careful with format(), don't use '{:}' because ``_id`` is
+                # not always a number.
+                raise KeyError('{}'.format(self._id))
 
             return
             #.if
@@ -526,6 +528,8 @@ class Model:
         key = self.__class__._serie_name() + SEP
         if self.__class__._AUTO_ID:
             if self._id < 0: self._id = self.__class__._uid()
+            # Be careful with format(), don't use '{:}' because ``_id`` is not
+            # always a number.
             key += '{}{}'.format(self._id, SEP)
             key_indexes = SEP.join([self.__class__._serie_name(),
                                     __class__._S_INDEXES, ''])
